@@ -11,8 +11,13 @@ sub index :Path :Args(1)
         my $report : Stash = $c->model('ReportsDB')->resultset('Report')->find($report_id);
 
         if ($report) {
-                $c->response->content_type ('text/plain');
-                $c->response->header ("Content-Disposition" => 'inline; filename="tap-'.$report_id.'.tap"');
+                if ($report->tap->tap_is_archive) {
+                        $c->response->content_type ('application/x-compressed');
+                        $c->response->header ("Content-Disposition" => 'inline; filename="tap-'.$report_id.'.tgz"');
+                } else {
+                        $c->response->content_type ('text/plain');
+                        $c->response->header ("Content-Disposition" => 'inline; filename="tap-'.$report_id.'.tap"');
+                }
                 $c->response->body ($report->tap->tap || "Error: No TAP for report $report_id.");
         } else {
                 $c->response->content_type ("text/plain");
