@@ -4,6 +4,7 @@ use 5.010;
 
 use strict;
 use warnings;
+use Tapper::Reports::Web::Util::Testrun;
 
 use parent 'Tapper::Reports::Web::Controller::Base';
 
@@ -11,7 +12,7 @@ use parent 'Tapper::Reports::Web::Controller::Base';
 
 Index function for /tapper/testruns/idlist/. Expects a comma separated
 list of testrun ids. The requested testruns are put into stash as has
-%testrunlist because we use the template /tapper/testruns/testrunlist.mas 
+%testrunlist because we use the template /tapper/testruns/testrunlist.mas
 which expects this.
 
 @param string - comma separated ids
@@ -25,26 +26,26 @@ which expects this.
 sub index :Path :Args(1)
 {
         my ( $self, $c, $idlist ) = @_;
-        
+
         my %testrunlist : Stash = ();
         my $filter_condition;
-        
+
         my @ids = split (qr/, */, $idlist);
-        
+
         $filter_condition = {
-                             rgt_testrun_id  => { '-in' => [@ids] }
+                             id  => { '-in' => [@ids] }
                             };
 
 
-
-        my $testruns = $c->model('ReportsDB')->resultset('View020TestrunOverview')->search
+        my $util = Tapper::Reports::Web::Util::Testrun->new();
+        my $testruns = $c->model('TestrunDB')->resultset('Testrun')->search
           (
            $filter_condition,
            {
-            order_by => 'rgt_testrun_id desc' }
+            order_by => 'me.id desc' }
           );
-        
-        %testrunlist = %{ $c->forward('/tapper/testruns/prepare_testrunlist', [ $testruns ]) };
+
+        %testrunlist = (testruns => $util->prepare_testrunlist($testruns) );
 
 }
 
